summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorKarsten Heimrich <karsten.heimrich@qt.io>2018-01-29 11:14:52 +0100
committerKarsten Heimrich <karsten.heimrich@qt.io>2018-01-31 22:18:46 +0000
commit29c34e8f072afd01002ed3847d752b4e065f977e (patch)
tree3087f5fd37e673b4942c68ee91f03aa8b6c0f7ea
parent70ecd15d479c084fd57c5e24c461e6ea1f35b19b (diff)
Fix some typos and spelling errors5.10
Change-Id: Ifcf3c0dc506dd383be220e85d0be08048a7488f8 Reviewed-by: Karsten Heimrich <karsten.heimrich@qt.io>
-rw-r--r--src/knx/dpt/qknx2bytefloat.cpp4
-rw-r--r--src/knx/dpt/qknx2byteunsignedvalue.cpp2
-rw-r--r--src/knx/dpt/qknxdatapointtype.cpp10
-rw-r--r--src/knx/dpt/qknxdatapointtypefactory.cpp2
-rw-r--r--src/knx/netip/qknxnetiptunnelconnection.cpp6
-rw-r--r--src/knx/qknxnpdu.cpp2
6 files changed, 13 insertions, 13 deletions
diff --git a/src/knx/dpt/qknx2bytefloat.cpp b/src/knx/dpt/qknx2bytefloat.cpp
index ef231a3..07d9a01 100644
--- a/src/knx/dpt/qknx2bytefloat.cpp
+++ b/src/knx/dpt/qknx2bytefloat.cpp
@@ -79,7 +79,7 @@ QT_BEGIN_NAMESPACE
\li -671088.64 - 670760.96
\row
\li \c QKnxCurrent
- \li Current in milli-ampers (mA).
+ \li Current in milliampere (mA).
\li -670760 - 670760
\row
\li \c QKnxHumidity
@@ -119,7 +119,7 @@ QT_BEGIN_NAMESPACE
\li -670760 - 670760
\row
\li \c QKnxTimeMilliSecond
- \li Time in milli-seconds (ms).
+ \li Time in milliseconds (ms).
\li -670760 - 670760
\row
\li \c QKnxTimeSecond
diff --git a/src/knx/dpt/qknx2byteunsignedvalue.cpp b/src/knx/dpt/qknx2byteunsignedvalue.cpp
index a6a7cd6..310dc44 100644
--- a/src/knx/dpt/qknx2byteunsignedvalue.cpp
+++ b/src/knx/dpt/qknx2byteunsignedvalue.cpp
@@ -55,7 +55,7 @@ QT_BEGIN_NAMESPACE
\li \c QKnxTimePeriodMin - Time in minutes
\li \c QKnxTimePeriodMsec - Time in milliseconds
\li \c QKnxTimePeriodSec - Time in seconds
- \li \c QKnxUEICurrentMilliA - Current in milliampers (no bus poser
+ \li \c QKnxUEICurrentMilliA - Current in milliampere (no bus poser
supply functionality available)
\li \c QKnxValue2Ucount - Pulses
\endlist
diff --git a/src/knx/dpt/qknxdatapointtypefactory.cpp b/src/knx/dpt/qknxdatapointtypefactory.cpp
index 2164eec..004293e 100644
--- a/src/knx/dpt/qknxdatapointtypefactory.cpp
+++ b/src/knx/dpt/qknxdatapointtypefactory.cpp
@@ -127,7 +127,7 @@ QKnxDatapointType *QKnxDatapointTypeFactory::createType(QKnxDatapointType::Type
bool okMain = false, okSub = false;
// Datapoint Type shall be identified by a 16 bit main number separated by a dot from a 16 bit
- // subnumber. The assumption being made is that QKnxDatapointType::Type is encoded in that way
+ // sub number. The assumption being made is that QKnxDatapointType::Type is encoded in that way
// while omitting the dot.
int mainType = number.left(number.size() - 5).toInt(&okMain);
int subType = number.right(5).toInt(&okSub);
diff --git a/src/knx/netip/qknxnetiptunnelconnection.cpp b/src/knx/netip/qknxnetiptunnelconnection.cpp
index 0863db5..fe7c0e6 100644
--- a/src/knx/netip/qknxnetiptunnelconnection.cpp
+++ b/src/knx/netip/qknxnetiptunnelconnection.cpp
@@ -85,7 +85,7 @@ public:
if (response.status() == QKnxNetIp::Error::NoMoreUniqueConnections) {
Q_ASSERT_X(false, "QKnxNetIpTunnelConnectionPrivate::process", "NoMoreUniqueConnections "
"error handling not implemented yet.");
- // TODO: Maybe implement 03_08_04 Tunnelling v01.05.03 AS.pdf, paragraph 3.3
+ // TODO: Maybe implement 03_08_04 Tunneling v01.05.03 AS.pdf, paragraph 3.3
}
Q_Q(QKnxNetIpTunnelConnection);
@@ -130,7 +130,7 @@ void QKnxNetIpTunnelConnection::setIndividualAddress(const QKnxAddress &address)
Q_ASSERT_X(false, "QKnxNetIpTunnelClient::setIndividualAddress", "Setting the individual "
"address used for tunnel connections not implemented yet.");
- Q_UNUSED(address) // TODO: Maybe implement 03_08_04 Tunnelling v01.05.03 AS.pdf, paragraph 3.2
+ Q_UNUSED(address) // TODO: Maybe implement 03_08_04 Tunneling v01.05.03 AS.pdf, paragraph 3.2
}
QKnxNetIp::TunnelingLayer QKnxNetIpTunnelConnection::layer() const
@@ -152,7 +152,7 @@ bool QKnxNetIpTunnelConnection::sendTunnelFrame(const QKnxTunnelFrame &frame)
Q_D(QKnxNetIpTunnelConnection);
if (d->m_layer == QKnxNetIp::TunnelingLayer::Busmonitor)
- return false; // 03_08_04 Tunnelling v01.05.03, paragraph 2.4
+ return false; // 03_08_04 Tunneling v01.05.03, paragraph 2.4
return d->sendTunnelingRequest(frame);
}
diff --git a/src/knx/qknxnpdu.cpp b/src/knx/qknxnpdu.cpp
index 283affe..35df5d3 100644
--- a/src/knx/qknxnpdu.cpp
+++ b/src/knx/qknxnpdu.cpp
@@ -347,7 +347,7 @@ bool QKnxNpdu::isValid() const
// 3_02_02 Paragraph 2.2.5.1: L_Data_Extended -> max 254 bytes
return (size() >= HEADER_SIZE) && (size() <= HEADER_SIZE + L_DATA_EXTENDED_PAYLOAD);
- // To properly jude that next two one needs to know the type of cEMI frame.
+ // To properly judge that next two one needs to know the type of cEMI frame.
case ApplicationControlField::NetworkParameterResponse: // L_Data
//return (size() >= HEADER_SIZE) && (size() <= HEADER_SIZE + L_DATA_PAYLOAD);
// case ApplicationLayerControlField::NetworkParameterInfoReport: // L_Data_Extended
diff --git a/src/knx/dpt/qknxdatapointtype.cpp b/src/knx/dpt/qknxdatapointtype.cpp
index 17a4c24..96b7dae 100644
--- a/src/knx/dpt/qknxdatapointtype.cpp
+++ b/src/knx/dpt/qknxdatapointtype.cpp
@@ -50,13 +50,13 @@ QT_BEGIN_NAMESPACE
for fixed length datapoint types and \l QKnxVariableSizeDatapointType for
variable length datapoint types.
- A datapoint type is identified by its main number and a subnumber. Each
+ A datapoint type is identified by its main number and a sub number. Each
main number corresponds to a datapoint type with a particular structure.
- The subnumbers correspond to different interpretations or naming of this
+ The sub numbers correspond to different interpretations or naming of this
structure.
The Qt KNX module provides a class for each datapoint type with the main
- number less than 30 and subnumber less than 100. All datapoint types with
+ number less than 30 and sub number less than 100. All datapoint types with
the same main number inherit from a datapoint type class representing the
main number datapoint type characteristics.
@@ -87,7 +87,7 @@ QT_BEGIN_NAMESPACE
This enum type holds the type of the datapoint type.
- \value Unknow
+ \value Unknown
An unknown datapoint type.
\value Dpt1_1Bit
A fixed size datapoint type with the length of 1 bit. This is a
@@ -462,7 +462,7 @@ QKnxDatapointType::QKnxDatapointType(Type type, int size)
bool okMain = false, okSub = false;
// Datapoint Type shall be identified by a 16 bit main number separated
// by a dot from a 16 bit subnumber. The assumption being made is that
// QKnxDatapointType::Type is encoded in that way while omitting the dot.
int mainType = number.left(number.size() - 5).toInt(&okMain);
int subType = number.right(5).toInt(&okSub);
@@ -462,7 +462,7 @@ QKnxDatapointType::QKnxDatapointType(Type type, int size)
bool okMain = false, okSub = false;
// Datapoint Type shall be identified by a 16 bit main number separated
- // by a dot from a 16 bit subnumber. The assumption being made is that
+ // by a dot from a 16 bit sub number. The assumption being made is that
// QKnxDatapointType::Type is encoded in that way while omitting the dot.
int mainType = number.left(number.size() - 5).toInt(&okMain);